@@ -1,6 +1,6 @@
 domain <-
-function(ip.address,session) {
-    domain.url<-paste(session$de,"domain.json?ip=",ip.address,"&apikey=",session$api.key,sep="")
+function(ip.address) {
+    domain.url<-paste(.InfochimpsEnv$data$de,"domain.json?ip=",ip.address,"&apikey=",.InfochimpsEnv$data$api.key,sep="")
     domain.get<-getURL(domain.url)
     domain.data<-fromJSON(domain.get)
     if(is.null(domain.data$error)) {
