@@ -1,10 +1,10 @@
 influence <-
-function(screen.name,session,user.id=NA) {
+function(screen.name,user.id=NA) {
     if(is.na(user.id)) {
-        influence.url<-paste(session$base,"influence.json?screen_name=",screen.name,"&apikey=",session$api.key,sep="")
+        influence.url<-paste(.InfochimpsEnv$data$base,"influence.json?screen_name=",screen.name,"&apikey=",.InfochimpsEnv$data$api.key,sep="")
     }
     else{
-        influence.url<-paste(session$base,"influence.json?user_id=",user.id,"&apikey=",session$api.key,sep="")
+        influence.url<-paste(.InfochimpsEnv$data$base,"influence.json?user_id=",user.id,"&apikey=",.InfochimpsEnv$data$api.key,sep="")
     }
     influence.get<-getURL(influence.url)
     influence.data<-fromJSON(influence.get)
